# autoENRICH
Automated Experimental Nuclear Resonance Information Calculated with HPC.

This is the public repository for release versions of the autoenrich software package. Periodic updates with new features will be migrated into this repository, but it is primarily for working on features and issues that affect actual users and developing tests.
